@@ -3,7 +3,7 @@
 
 ###################
 #    This tools run scripts and display the result in a Web Interface.
-#    Copyright (C) 2021  Maurice Lambert
+#    Copyright (C) 2021, 2022  Maurice Lambert
 
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ license = "GPL-3.0 License"
 __url__ = "https://github.com/mauricelambert/WebScripts"
 
 copyright = """
-WebScripts  Copyright (C) 2021  Maurice Lambert
+WebScripts  Copyright (C) 2021, 2022  Maurice Lambert
 This program comes with ABSOLUTELY NO WARRANTY.
 This is free software, and you are welcome to redistribute it
 under certain conditions.
@@ -264,7 +264,6 @@ def get_environ(
 
     script_env["USER"] = json.dumps(user.get_dict())
     script_env["SCRIPT_CONFIG"] = json.dumps(script.get_JSON_API())
-    script_env["PYTHONSTARTUP"] = path.join(lib_directory, "pre_scripts.py")
 
     to_delete = [
         key
@@ -347,7 +346,9 @@ def check_categories_scripts_access(
 @log_trace
 def decode_output(data: bytes) -> str:
 
-    """This function decode outputs (try somes encoding)."""
+    """
+    This function decodes outputs (try somes encoding).
+    """
 
     output = None
     for encoding in get_encodings():
