@@ -3,7 +3,7 @@
 
 ###################
 #    This tools run scripts and display the result in a Web Interface.
-#    Copyright (C) 2021  Maurice Lambert
+#    Copyright (C) 2021, 2022  Maurice Lambert
 
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -19,10 +19,12 @@
 #    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 ###################
 
-"""This tools run scripts and display the result in a Web Interface.
+"""
+This tools run scripts and display the result in a Web Interface.
 
 This file implement the hardening audit of the WebScripts installation and
-configuration."""
+configuration.
+"""
 
 __version__ = "0.3.0"
 __author__ = "Maurice Lambert"
@@ -38,7 +40,7 @@ license = "GPL-3.0 License"
 __url__ = "https://github.com/mauricelambert/WebScripts"
 
 copyright = """
-WebScripts  Copyright (C) 2021  Maurice Lambert
+WebScripts  Copyright (C) 2021, 2022  Maurice Lambert
 This program comes with ABSOLUTELY NO WARRANTY.
 This is free software, and you are welcome to redistribute it
 under certain conditions.
